#
# Magic Keys
#

DB='default'
cAlias='|'
kAbove='above'
kArgs='args'
kCast='as_number'
kCols='cols'
kDoc='+doc'
kExt='file_ext'
kFunc='function'
kGroup='group'
kInner='inner'
kJoinType='join_type'
kKeepJoin='keep_join'
kReverse='descend'
kSave='save'
kSelect='select'
kSkip='skip'
kSkipSave='skip_save'
kSkipUpload='skip_upload'
kSort='sort'
kSQL='sql'
kUniq='ensure_unique'
